# Table of Contents

- [automations](<./automations.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Automations](<./Automations.md>)
  - [Overview](<./Automations/Overview.md>)
  - [Automation Parameters](<./Automations/Automation-Parameters.md>)
  - [Triggers](<./Automations/Triggers.md>)
  - [Conditions](<./Automations/Conditions.md>)
  - [Actions](<./Automations/Actions.md>)
  - [Creating an Automation](<./Automations/Creating-an-Automation.md>)
  - [Creating an Automation by Copying an Existing Automation](<./Automations/Creating-an-Automation-by-Copying-an-Existing-Automation.md>)
  - [Sending a Webhook from an Automation](<./Automations/Sending-a-Webhook-from-an-Automation.md>)
  - [Managing Automations](<./Automations/Managing-Automations.md>)
  - [Viewing Statistics for Automations](<./Automations/Viewing-Statistics-for-Automations.md>)
  - [Processing Time](<./Automations/Processing-Time.md>)
  - [Best Practices](<./Automations/Best-Practices.md>)
